@@ -52,9 +52,12 @@ from distutils.util import split_quoted
 from distutils.errors import DistutilsError
 
 try:
-    from setuptools import dep_util
+    from setuptools import modified
 except ImportError:
-    from distutils import dep_util
+    try:
+        from setuptools import dep_util as modified
+    except ImportError:
+        from distutils import dep_util as modified
 
 try:
     from packaging.version import Version
@@ -124,7 +127,7 @@ def cython_run(
         alldeps = [source]
         for dep in depends:
             alldeps += glob.glob(dep)
-        if not (force or dep_util.newer_group(alldeps, target)):
+        if not (force or modified.newer_group(alldeps, target)):
             log.debug("skipping '%s' -> '%s' (up-to-date)",
                       source, target)
             return
@@ -197,18 +200,6 @@ def get_config_vars(*names):
     values = fix_config_vars(names, values)
     return values
 
-from distutils.unixccompiler import UnixCCompiler
-rpath_option_orig = UnixCCompiler.runtime_library_dir_option
-def rpath_option(compiler, dir):
-    option = rpath_option_orig(compiler, dir)
-    if sys.platform[:5] == 'linux':
-        if option.startswith('-R'):
-            option =  option.replace('-R', '-Wl,-rpath,', 1)
-        elif option.startswith('-Wl,-R'):
-            option =  option.replace('-Wl,-R', '-Wl,-rpath,', 1)
-    return option
-UnixCCompiler.runtime_library_dir_option = rpath_option
-
 # --------------------------------------------------------------------
 
 class PetscConfig:
@@ -308,9 +299,13 @@ class PetscConfig:
         if sys.platform != 'win32':
             # if DESTDIR is set, then we're building against PETSc in a staging
             # directory, but rpath needs to point to final install directory.
-            rpath = strip_prefix(self.DESTDIR, self['PETSC_LIB_DIR'])
-            petsc_lib['runtime_library_dirs'].append(rpath)
-
+            rpath = [strip_prefix(self.DESTDIR, self['PETSC_LIB_DIR'])]
+            if sys.modules.get('petsc') is not None:
+                if sys.platform == 'darwin':
+                    rpath = ['@loader_path/../../petsc/lib']
+                else:
+                    rpath = ['$ORIGIN/../../petsc/lib']
+            petsc_lib['runtime_library_dirs'].extend(rpath)
         # Link in extra libraries on static builds
         if self['BUILDSHAREDLIB'] != 'yes':
             petsc_ext_lib = split_quoted(self['PETSC_EXTERNAL_LIB_BASIC'])
@@ -374,14 +369,6 @@ class PetscConfig:
             linker_so    = PLD_SHARED,
             )
         compiler.shared_lib_extension = so_ext
-        #
-        if sys.platform == 'darwin':
-            for attr in ('preprocessor',
-                         'compiler', 'compiler_cxx', 'compiler_so',
-                         'linker_so', 'linker_exe'):
-                compiler_cmd = getattr(compiler, attr, [])
-                while '-mno-fused-madd' in compiler_cmd:
-                    compiler_cmd.remove('-mno-fused-madd')
 
     def log_info(self):
         PETSC_DIR  = self['PETSC_DIR']
@@ -597,26 +584,6 @@ class build_ext(_build_ext):
         self.set_undefined_options('build',
                                    ('petsc_dir',  'petsc_dir'),
                                    ('petsc_arch', 'petsc_arch'))
-        if ((sys.platform.startswith('linux') or
-             sys.platform.startswith('gnu') or
-             sys.platform.startswith('sunos')) and
-            sysconfig.get_config_var('Py_ENABLE_SHARED')):
-            py_version = sysconfig.get_python_version()
-            bad_pylib_dir = os.path.join(sys.prefix, "lib",
-                                         "python" + py_version,
-                                         "config")
-            try:
-                self.library_dirs.remove(bad_pylib_dir)
-            except ValueError:
-                pass
-            pylib_dir = sysconfig.get_config_var("LIBDIR")
-            if pylib_dir not in self.library_dirs:
-                self.library_dirs.append(pylib_dir)
-            if pylib_dir not in self.rpath:
-                self.rpath.append(pylib_dir)
-            if sys.exec_prefix == '/usr':
-                self.library_dirs.remove(pylib_dir)
-                self.rpath.remove(pylib_dir)
 
     def _copy_ext(self, ext):
         extclass = ext.__class__
