@@ -116,14 +116,12 @@ F = PETSc.Mat().create()
 F.setSizes([n, n])
 F.setType('aij')
 F.setPreallocationNNZ(3)
-F.setUp()
 nep.setFunction(pde.formFunction, F)
 
 J = PETSc.Mat().create()
 J.setSizes([n, n])
 J.setType('aij')
 J.setPreallocationNNZ(3)
-J.setUp()
 nep.setJacobian(pde.formJacobian, J)
 
 nep.setTolerances(tol=1e-9)
